@@ -9,7 +9,7 @@ require Exporter;
 
 our @ISA = ("Exporter");
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 our @EXPORT = qw(sapply mapply happly tapply initial_array initial_matrix order
                  rank sort_array reverse_array repeat rep copy paste seq c test 
@@ -791,8 +791,8 @@ Remove repeated lines
 
 =item C<l.sort file [sort_function]>
 
-Sort lines by certain function. Function should looks like C<sub {$a <=> $b}>,
-C<sub {$_[0] cmp $_[1]}> or C<{$a <=> $b}>. That means you can use C<$a>/C<$b> or
+Sort lines by certain function. Function should looks like C<sub {$a E<lt>=E<gt> $b}>,
+C<sub {$_[0] cmp $_[1]}> or C<{$a E<lt>=E<gt> $b}>. That means you can use C<$a>/C<$b> or
 C<$_[0]>/C<$_[1]> to represent two items while sorting.
 
 =item C<l.sapply file [apply_function]>
